library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity DM9000A_IF is
port(
	-- host side signals (Avalon Bus)
	signal CLK		: in std_logic;
	signal oINT		: out std_logic;
	signal iCMD		: in std_logic;
	signal iCS_n	: in std_logic;
	signal iRST_n	: in std_logic;
	signal iIORD_n	: in std_logic;
	signal iIOWR_n	: in std_logic;
	
	signal iDATA	: in std_logic_vector(15 downto 0);
	signal oDATA	: out std_logic_vector(15 downto 0);

	-- peripheral side signals (DM9000A)
	signal INT		: in std_logic;
	signal CMD		: out std_logic;
	signal CS_n		: out std_logic;
	signal RST_n	: out std_logic;
	signal IORD_n	: out std_logic;
	signal IOWR_n	: inout std_logic;
	
	signal data : inout std_logic_vector(15 downto 0));
end entity DM9000A_IF;

architecture behaviour of DM9000A_IF is
	signal reg_data: std_logic_vector(15 downto 0);
begin
	oINT <= INT;
	oDATA <= data;
	data <= reg_data when IOWR_n='0' and iRST_n='1' else (others=>'Z');

	process(CLK, iRST_n)
	begin
		if CLK'event and CLK='0'  then
			if iRST_n = '0' then
				CMD <= '0';
				CS_n <= '1';
				RST_n <= '0';
				IORD_n <= '1';
				IOWR_n <= '1';
			else
				CMD <= iCMD;
				CS_n <= iCS_n;
				RST_n <= '1';
				IORD_n <= iIORD_n or iCS_n;
				IOWR_n <= iIOWR_n or iCS_n;
			end if;
			reg_data <= iDATA;
		end if;
	end process;
end behaviour;